@@ -552,6 +552,7 @@ horizonForecastsCompiled.ARMA <- function( obj, data, horizons=1:4,
   storage.mode(obj$B)  <- "double"
   storage.mode(C)  <- "double"
   storage.mode(TREND)  <- "double"
+   #.Fortran(rmaprj_sym,
    .Fortran("rmaprj",
                   proj=proj,    
                   as.integer(discard.before), 
@@ -575,8 +576,7 @@ horizonForecastsCompiled.ARMA <- function( obj, data, horizons=1:4,
                   matrix(double(1),is,is),  # scratch array
                   double(is),         # scratch array
                   integer(is*is),         # scratch array IPIV
-                  DUP=.DSEflags()$DUP,
-		  PACKAGE="dse"
+                  PACKAGE="dse"
 		  )$proj
 }
 
@@ -628,6 +628,7 @@ horizonForecastsCompiled.SS <- function( obj, data, horizons=1:4,
      storage.mode(z)  <- "double"
      storage.mode(P)  <- "double"
      IS <- max(n,p)
+     #.Fortran(kfprj_sym,
      .Fortran("kfprj",
                   proj= proj, 
                   as.integer(discard.before), 
@@ -659,8 +660,7 @@ horizonForecastsCompiled.SS <- function( obj, data, horizons=1:4,
 	          rep(double(1),IS), # ZZ
 	          rep(double(1),IS), # WW		   
                   integer(IS*IS),         # scratch array IPIV
- 		  DUP=.DSEflags()$DUP,
-		  PACKAGE="dse"
+ 		  PACKAGE="dse"
 		  )$proj
 }
 
@@ -928,6 +928,7 @@ forecastCov.TSdata <- function(obj, ..., data=NULL,
    if (compiled)
      {storage.mode(cov) <-"double"
       storage.mode(err) <-"double"
+      #r <- .Fortran(datepr_sym,
       r <- .Fortran("datepr",
                   forecastCov=cov,    
                   as.integer(discard.before), 
@@ -937,7 +938,6 @@ forecastCov.TSdata <- function(obj, ..., data=NULL,
                   as.integer(p), 
                   predictT=as.integer(TT), 
                   err, 
-		  DUP=.DSEflags()$DUP,
 		  PACKAGE="dse"
 		  ) [c("forecastCov","sample.size")]
      }
@@ -1094,6 +1094,7 @@ forecastCovCompiled.ARMA <- function(model, data, horizons=1:12 ,
   storage.mode(model$B)  <- "double"
   storage.mode(C)  <- "double"
   storage.mode(TREND)  <- "double"
+  #.Fortran(rmaepr_sym,
   .Fortran("rmaepr",
                   forecastCov=cov,    
                   as.integer(discard.before), 
@@ -1119,8 +1120,7 @@ forecastCovCompiled.ARMA <- function(model, data, horizons=1:12 ,
                   matrix(double(1),is,is),  # scratch array
                   double(is),         # scratch array
                   integer(is*is),         # scratch array IPIV
-                  DUP=.DSEflags()$DUP,
-		  PACKAGE="dse"
+                  PACKAGE="dse"
 		  )[c("forecastCov","sample.size")]
 }
 
@@ -1183,6 +1183,7 @@ forecastCovCompiled.SS <- function(model, data, horizons=1:12 ,
      storage.mode(z) <-"double"
      storage.mode(P) <-"double"
      IS <- max(n,p)
+     #.Fortran(kfepr_sym,
      .Fortran("kfepr",
                   forecastCov=cov,    
                   as.integer(discard.before), 
@@ -1216,8 +1217,7 @@ forecastCovCompiled.SS <- function(model, data, horizons=1:12 ,
 	          rep(double(1),IS), # ZZ
 	          rep(double(1),IS), # WW		   
                   integer(IS*IS),         # scratch array IPIV
- 		  DUP=.DSEflags()$DUP,
-		  PACKAGE="dse"
+ 		  PACKAGE="dse"
 		  ) [c("forecastCov","sample.size")]
 }
 
